==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cannons/dialogs_es.lua <==

dialogId("del-v-dve", "font_big", "See? This ship had two gun decks. It must have been a man-of-war. The acrid smell of gunpowder still seems to linger in the air...")
dialogStr("¿Ves? Este barco tuvo dos cañones. Este debió de haber sido un buque de guerra. El olor ocre de la pólvora todavía parece flotar en el aire...")


dialogId("del-m-voda", "font_small", "You mean, in the water.")
dialogStr("Tu quieres decir, en el agua.")


dialogId("del-m-ci", "font_small", "Whose ship was she? Maybe she served under admiral Nelson... or captain Hornblower.")
dialogStr("¿De cuál barco era ella? Quizás ella sirvió bajo el admirante Nelson... o el capitán Hornblower.")


dialogId("del-v-splet", "font_big", "No, I think you`re about a hundred years off.")
dialogStr("No, yo creo que llevas fuera cerca de un siglo.")


dialogId("del-v-mec", "font_big", "I have a feeling we`re going to need that sword.")
dialogStr("Presiento que vamos a necesitar esa espada.")


dialogId("del-m-tus", "font_small", "You and your 'feelings`. Besides, we`re not supposed to be giving any hints.")
dialogStr("Tu y tus \"presentimientos\". Además, se supone que nosotros no demos pistas.")


dialogId("del-m-jedn0", "font_small", "That was a little too simple, wasn`t it?")
dialogStr("Eso fué un poquitín muy simple, ¿No crees?")


dialogId("del-m-jedn1", "font_small", "Could it possibly be so simple?")
dialogStr("¿Será posible que haya sido tan simple?")


dialogId("del-m-jedn2", "font_small", "There must be some kind of mistake.")
dialogStr("Debe de haber alguna clase de error.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cannons/dialogs_es.lua <==

dialogId("del-v-dve", "font_big", "See? This ship had two gun decks. It must have been a man-of-war. The acrid smell of gunpowder still seems to linger in the air...")
dialogStr("¿Ves? Este barco tuvo dos cañones. Este debió de haber sido un buque de guerra. El olor ocre de la pólvora todavía parece flotar en el aire...")


dialogId("del-m-voda", "font_small", "You mean, in the water.")
dialogStr("Tu quieres decir, en el agua.")


dialogId("del-m-ci", "font_small", "Whose ship was she? Maybe she served under admiral Nelson... or captain Hornblower.")
dialogStr("¿De cuál barco era ella? Quizás ella sirvió bajo el admirante Nelson... o el capitán Hornblower.")


dialogId("del-v-splet", "font_big", "No, I think you’re about a hundred years off.")
dialogStr("No, yo creo que llevas fuera cerca de un siglo.")


dialogId("del-v-mec", "font_big", "I have a feeling we’re going to need that sword.")
dialogStr("Presiento que vamos a necesitar esa espada.")


dialogId("del-m-tus", "font_small", "You and your 'feelings’. Besides, we’re not supposed to be giving any hints.")
dialogStr("Tu y tus \"presentimientos\". Además, se supone que nosotros no demos pistas.")


dialogId("del-m-jedn0", "font_small", "That was a little too simple, wasn’t it?")
dialogStr("Eso fué un poquitín muy simple, ¿No crees?")


dialogId("del-m-jedn1", "font_small", "Could it possibly be so simple?")
dialogStr("¿Será posible que haya sido tan simple?")


dialogId("del-m-jedn2", "font_small", "There must be some kind of mistake.")
dialogStr("Debe de haber alguna clase de error.")
